@@ -2,7 +2,7 @@
 """
 Appindicator integration plugin.
 
-Rewriten from Ubuntu Ayatana Integration plugin
+Rewritten from Ubuntu Ayatana Integration plugin
 2013 Denis Borenko <borenko@rambler.ru>
 2017 Philipp Hörist <philipp@hoerist.com>
 :license: GPLv3
@@ -14,33 +14,36 @@ import gi
 from gi.repository import Gtk, GLib, Gdk
 
 try:
-    gi.require_version('AyatanaAppIndicator3', '0.1')
-    from gi.repository import AyatanaAppIndicator3 as appindicator
-    ERRORMSG = None
+    gi.require_version('AppIndicator3', '0.1')
+    from gi.repository import AppIndicator3 as appindicator
+    HAS_ERROR = False
 except (ValueError, ImportError):
-    ERRORMSG = 'Please install libappindicator3'
+    try:
+        gi.require_version('AyatanaAppIndicator3', '0.1')
+        from gi.repository import AyatanaAppIndicator3 as appindicator
+        HAS_ERROR = False
+    except (ValueError, ImportError):
+        HAS_ERROR = True
 
 from gajim.common import app, ged
 from gajim.common import configpaths
 from gajim.plugins import GajimPlugin
 from gajim.plugins.helpers import log_calls
-
-# Since Gajim 1.1.0 _() has to be imported
-try:
-    from gajim.common.i18n import _
-except ImportError:
-    pass
+from gajim.plugins.plugins_i18n import _
 
 
 class AppindicatorIntegrationPlugin(GajimPlugin):
 
     @log_calls("AppindicatorIntegrationPlugin")
     def init(self):
-        if ERRORMSG:
-            self.activatable = False
-            self.available_text += ERRORMSG
-            return
+        self.description = _('This plugin integrates Gajim with the Ayatana '
+                             'AppIndicator.')
         self.config_dialog = None
+        if HAS_ERROR:
+            self.activatable = False
+            self.available_text += _('Please install libappindicator3')
+            return
+
         self.events_handlers = {'our-show': (ged.GUI2,
                                              self.set_indicator_icon)}
         self.windowstate = None
@@ -54,10 +57,11 @@ class AppindicatorIntegrationPlugin(GajimPlugin):
         self.offline_icon = 'org.gajim.Gajim-symbolic'
         self.connected = 0
 
-        self.connect_menu_item = Gtk.MenuItem('Connect')
+        self.connect_menu_item = Gtk.MenuItem(label=_('Connect'))
         self.connect_menu_item.connect("activate", self.connect)
 
-        self.show_gajim_menu_item = Gtk.MenuItem('Show/hide roster')
+        self.show_gajim_menu_item = Gtk.MenuItem(
+            label=_('Show/hide contact list'))
         self.show_gajim_menu_item.connect("activate", self.roster_raise)
         self.show_gajim_menu_item.show()
 
@@ -67,7 +71,7 @@ class AppindicatorIntegrationPlugin(GajimPlugin):
         itemExitSeparator = Gtk.SeparatorMenuItem()
         itemExitSeparator.show()
 
-        itemExit = Gtk.MenuItem('Exit')
+        itemExit = Gtk.MenuItem(label=_('Quit'))
         itemExit.connect("activate", self.on_exit_menuitem_activate)
         itemExit.show()
 
@@ -83,7 +87,7 @@ class AppindicatorIntegrationPlugin(GajimPlugin):
             'Gajim', self.offline_icon,
             appindicator.IndicatorCategory.COMMUNICATIONS)
         self.indicator.set_icon_theme_path(configpaths.get('ICONS'))
-        self.indicator.set_attention_icon('mail-unread')
+        self.indicator.set_attention_icon_full('mail-unread', 'New Message')
         self.indicator.set_status(appindicator.IndicatorStatus.ACTIVE)
         self.indicator.set_menu(self.menu)
 
@@ -182,15 +186,7 @@ class AppindicatorIntegrationPlugin(GajimPlugin):
 
         event.time = when
         if key not in self.events:
-            icon = None
-            if app.config.get("show_avatars_in_roster"):
-                pix = app.contacts.get_avatar(account, jid, size=16)
-                icon = Gtk.Image()
-                icon.set_from_pixbuf(pix)
-            item = Gtk.ImageMenuItem(contact + " (1)")
-            if icon:
-                item.set_image(icon)
-                item.set_always_show_image(True)
+            item = Gtk.MenuItem(label=contact + " (1)")
             item.connect("activate", self.event_raise, event)
             item.show()
             self.menu.insert(item, self.menuEventInsertIndex)
